DbConfig

Struct DbConfig 

pub struct DbConfig { /* private fields */ }
PostgreSQL configuration. PostgreSQL connection configuration.

Implementations

Source

impl Config

pub fn new() -> Result<Self>

Creates a new Config from environment variables with default PG_ prefix.

pub fn builder<'a>() -> ConfigBuilder<'a>

Creates a new ConfigBuilder for custom configuration.

pub fn max_connections(&self) -> u32

Returns the maximum number of connections in the pool.

pub fn min_connections(&self) -> u32

Returns the minimum number of connections in the pool.

pub fn acquire_timeout(&self) -> u64

Returns the connection acquire timeout in seconds.

pub fn idle_timeout(&self) -> u64

Returns the idle connection timeout in seconds.

pub fn max_lifetime(&self) -> u64

Returns the maximum lifetime of a connection in seconds.

pub fn database(&self) -> Option<&str>

Returns the database name, if set.

pub fn username(&self) -> Option<&str>

Returns the database username, if set.

pub fn password(&self) -> Option<&str>

Returns the database password, if set.

pub fn root_database(&self) -> Option<&str>

Returns the root database name, if set.

pub fn address(&self) -> &str

Returns the PostgreSQL connection address.

pub fn root_address(&self) -> &str

Returns the PostgreSQL root connection address.