pub struct DbConfig { /* private fields */ }Expand description
PostgreSQL configuration. PostgreSQL connection configuration.
Implementations
Sourceimpl Config
impl Config
Sourcepub fn new() -> Result<Self>
pub fn new() -> Result<Self>
Creates a new Config from environment variables with default PG_ prefix.
Sourcepub fn builder<'a>() -> ConfigBuilder<'a>
pub fn builder<'a>() -> ConfigBuilder<'a>
Creates a new ConfigBuilder for custom configuration.
Sourcepub fn max_connections(&self) -> u32
pub fn max_connections(&self) -> u32
Returns the maximum number of connections in the pool.
Sourcepub fn min_connections(&self) -> u32
pub fn min_connections(&self) -> u32
Returns the minimum number of connections in the pool.
Sourcepub fn acquire_timeout(&self) -> u64
pub fn acquire_timeout(&self) -> u64
Returns the connection acquire timeout in seconds.
Sourcepub fn idle_timeout(&self) -> u64
pub fn idle_timeout(&self) -> u64
Returns the idle connection timeout in seconds.
Sourcepub fn max_lifetime(&self) -> u64
pub fn max_lifetime(&self) -> u64
Returns the maximum lifetime of a connection in seconds.
Sourcepub fn root_database(&self) -> Option<&str>
pub fn root_database(&self) -> Option<&str>
Returns the root database name, if set.
Sourcepub fn root_address(&self) -> &str
pub fn root_address(&self) -> &str
Returns the PostgreSQL root connection address.